/**
 * Sets a Cookie with the given name and value.
 *
 * name       Name of the cookie
 * value      Value of the cookie
 * [expires]  Expiration date of the cookie (default: end of current session)
 * [path]     Path where the cookie is valid (default: path of calling document)
 * [domain]   Domain where the cookie is valid
 *              (default: domain of calling document)
 * [secure]   Boolean value indicating if the cookie transmission requires a
 *              secure transmission
 */
function setCookie(name, value)
{
    var the_date = new Date("December 31, 2023"); 
    var the_cookie_date = the_date.toGMTString();

    document.cookie= name + "=" + escape(value) + "; expires=" + the_date.toGMTString() + "; path=/";
}

/**
 * Gets the value of the specified cookie.
 *
 * name  Name of the desired cookie.
 *
 * Returns a string containing value of specified cookie,
 *   or false if cookie does not exist.
 */
function getCookie(name)
{
  if (document.cookie == '') 
  { 
    // there's no cookie, so go no further 
    return null;
  } 
  else 
  { 
    // there is a cookie 
    var firstChar, lastChar; 
    var theBigCookie = document.cookie; 
    firstChar = theBigCookie.indexOf(name);    // find the start of 'name' 

    if (firstChar != -1) 
    { 
      // if you found the cookie
      firstChar += name.length + 1; // skip 'name' and '=' 
      lastChar = theBigCookie.indexOf(';', firstChar); // Find the end of the value string (i.e. the next ';'). 

      if(lastChar == -1) 
        lastChar = theBigCookie.length; 

      return unescape(theBigCookie.substring(firstChar, lastChar)); 
    } 
    else 
    { 
      // If there was no cookie of that name, return false. 
      return null; 
    } 
  } 
} 

function getBooleanCookie(name)
{
  var cv = getCookie(name)
  if (cv == null)
    return null

  if (cv.indexOf("true") != -1)
    return true
  else
    return false
}
/**
 * Deletes the specified cookie.
 *
 * name      name of the cookie
 * [path]    path of the cookie (must be same as path used to create cookie)
 * [domain]  domain of the cookie (must be same as domain used to create cookie)
 */
function deleteCookie(name, path, domain)
{
    if (getCookie(name))
    {
        document.cookie = name + "=" + 
            ((path) ? "; path=" + path : "") +
            ((domain) ? "; domain=" + domain : "") +
            "; expires=Thu, 01-Jan-70 00:00:01 GMT";
    }
}


function readSettings()
{
  var cookieVal = getBooleanCookie("showToc");
  if (cookieVal != null)
    showToC = cookieVal;

  var cookieVal = getBooleanCookie("showExamples");
  if (cookieVal != null)
    showExamples = cookieVal;

  var cookieVal = getCookie("exceptions");
  if (cookieVal != null)
    exceptions = cookieVal;

  var cookieVal = getCookie("annotations");
  if (cookieVal != null)
    annotations = cookieVal;

  var cookieVal = getBooleanCookie("showImages");
  if (cookieVal != null)
    showImages = cookieVal;

  var cookieVal = getBooleanCookie("autoLinks");
  if (cookieVal != null)
    autoLinks = cookieVal;

  readASOPsettings()
}


function readASOPsettings()
{
  if (!readASOPprop)
    return
    
  readASOPprop = false

  var strToInt = new Array(0,1,2)
  
  var the_cookie = getCookie("ASOP");
  if (the_cookie != null)
  {  
    var separated_values = the_cookie.split("/"); 
 
    var property_value = ""; 
    var i = 0;
    
    for (var loop = 1; loop < separated_values.length; loop++) 
    { 
      property_value = separated_values[loop]; 
      var broken_info = property_value.split(":");

      if (broken_info[0].indexOf("Pre") == 0)
      {
         i = ASOPproperties.length - 1
      }
      else
	{
        var chap = broken_info[0].charAt(0)
       
        var looking = true
        while (i < ASOPproperties.length && looking)
        {
          if (ASOPproperties[i][0].id == chap || (ASOPproperties[i][0].id == 'Z' && chap >= 'O'))
            looking = false;
          
          i++
        }
        i--

        if (looking)
          return
      }
  
      // Found correct chapter, find section
      var p = ASOPproperties[i]
      looking = true
      var j = 0

      while (j < p.length && looking)
      {
        if (p[j].id.indexOf(broken_info[0]) >= 0)
          looking = false
          
        j++
      }
    

      if (looking)
        return

      j--

      if (broken_info[1].charAt(0) == '0')
        p[j].val = 0
      else if (broken_info[1].charAt(0) == '1')
        p[j].val = 1
      else if (broken_info[1].charAt(0) == '2')
        p[j].val = 2


      if (j > 0)
        p[0].open = true
    } 
  }
}
